==> tablib-0.9.7.tar.gz: tablib-0.9.7/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

from distutils.core import setup


def publish():
    """Publish to PyPi"""
    os.system("python setup.py sdist upload")

if sys.argv[-1] == "publish":
    publish()
    sys.exit()

required = []

if sys.version_info[:2] < (2,6):
    required.append('simplejson')

setup(
    name='tablib',
    version='0.9.7',
    description='Format agnostic tabular data library (XLS, JSON, YAML, CSV)',
    long_description=open('README.rst').read() + '\n\n' +
                     open('HISTORY.rst').read(),
    author='Kenneth Reitz',
    author_email='me@kennethreitz.com',
    url='http://tablib.org',
    packages= [
        'tablib', 'tablib.formats',
        'tablib.packages',
        'tablib.packages.xlwt',
        'tablib.packages.openpyxl',
        'tablib.packages.openpyxl.shared',
        'tablib.packages.openpyxl.reader',
        'tablib.packages.openpyxl.writer',
        'tablib.packages.yaml',
        'tablib.packages.unicodecsv'
    ],
    install_requires=required,
    license='MIT',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
    ),
)

==> tablib-0.9.8.tar.gz: tablib-0.9.8/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

from distutils.core import setup



if sys.argv[-1] == 'publish':
    os.system("python setup.py sdist upload")
    sys.exit()

if sys.argv[-1] == 'speedups':
    try:
        import pip
    except ImportError:
        print('Pip required.')
        sys.exit(1)

    os.system('pip install simplejson pyyaml')
    sys.exit()

if sys.argv[-1] == 'test':
    try:
        import py
    except ImportError:
        print('py.test required.')
        sys.exit(1)

    os.system('pytest test_tablib.py')
    sys.exit()

required = []

if sys.version_info[:2] < (2,6):
    required.append('simplejson')

setup(
    name='tablib',
    version='0.9.8',
    description='Format agnostic tabular data library (XLS, JSON, YAML, CSV)',
    long_description=open('README.rst').read() + '\n\n' +
                     open('HISTORY.rst').read(),
    author='Kenneth Reitz',
    author_email='me@kennethreitz.com',
    url='http://tablib.org',
    packages= [
        'tablib',
        'tablib.formats',
        'tablib.packages',
        'tablib.packages.xlwt',
        'tablib.packages.openpyxl',
        'tablib.packages.odf',
        'tablib.packages.openpyxl.shared',
        'tablib.packages.openpyxl.reader',
        'tablib.packages.openpyxl.writer',
        'tablib.packages.yaml',
        'tablib.packages.unicodecsv'
    ],
    install_requires=required,
    license='MIT',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
    ),
)
